<?php

/**
 * @file
 * Mocks Drupal's drupal_static function.
 *
 * Since the global function "drupal_static" does not exist in the
 * testing environment, we need to make sure this function is
 * callable.
 */

namespace Drupal\blizz_dynamic_entitylist\Services;

if (!function_exists('drupal_static')) {

  /**
   * {@inheritdoc}
   *
   * This is an exact copy of Drupal's drupal_static function in
   * file bootstrap.inc. It is mocked here to enable PHPUnit to run.
   */
  function &drupal_static($name, $default_value = NULL, $reset = FALSE) {
    static $data = [], $default = [];
    // First check if dealing with a previously defined static variable.
    if (isset($data[$name]) || array_key_exists($name, $data)) {
      // Non-NULL $name and both $data[$name] and $default[$name] statics exist.
      if ($reset) {
        // Reset pre-existing static variable to its default value.
        $data[$name] = $default[$name];
      }
      return $data[$name];
    }
    // Neither $data[$name] nor $default[$name] static variables exist.
    if (isset($name)) {
      if ($reset) {
        // Reset was called before a default is set and yet a variable must be
        // returned.
        return $data;
      }
      // First call with new non-NULL $name. Initialize a new static variable.
      $default[$name] = $data[$name] = $default_value;
      return $data[$name];
    }
    // Reset all: ($name == NULL). This needs to be done one at a time so that
    // references returned by earlier invocations of drupal_static() also get
    // reset.
    foreach ($default as $name => $value) {
      $data[$name] = $value;
    }
    // As the function returns a reference, the return should always be a
    // variable.
    return $data;
  }

}
